/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's Compassionate  *
* Release: The Impact of the First Step Act and COVID-19 Pandemic Report file and create *
* a SAS dataset.                                                                         *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer.                            *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located.                                     *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\USSC_Comp_Release_Public.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = USSC_Com ;

DATA library.&dataset ;
INFILE datafile LRECL=182;
INPUT
   USSCIDN  1-7             OS_NEWCNVTN  8-10        OS_NEWRACE  11-13     
   OS_NEWCIT  14-16         OS_ACCAP  17-19          OS_CAROFFAP  20-22    
   OS_WEAPSOC  23-25        OS_OFFGUIDE  26-28       CRCIRCDIST  29-31     
   CRGOVOBJ  32-34          CRMONCIRC  35-37         MOTSTAT  38-40        
   CRSENTMON  41-43         OP_MONSEX  44-46         SAFEYN  47-49         
   AGGROLYN  50-52          MITROLYN  53-55          OBSTRCYN  56-58       
   OP_XCRHISSR  59-61       GUNDUM  62-64            TSERVEDM  65-72       
   TSERVEDP  73-80          REDUCTP  81-88           SLENGTH  89-91        
   CRAGECAT  92-94          ORIGINATOR  95-97        NONDUP_GREAS1  98-100 
   NONDUP_GREAS2  101-103   NONDUP_GREAS3  104-106   NONDUP_GREAS4  107-109
   NONDUP_GREAS5  110-112   GC_COVID_ANY  113-115    COVID_CAT  116-118    
   CRSENTYPE  119-121       COL_CRSENTYPE  122-124   UNDUP_GROUPD1  125-127
   UNDUP_GROUPD2  128-130   UNDUP_GROUPD3  131-133   UNDUP_GROUPD4  134-136
   UNDUP_GROUPD5  137-139   UNDUP_GROUPD6  140-142   D_ANYEXHAUST  143-145 
   D_ONLYEXHAUST  146-148   D_ANY3553PROT  149-151   D_ONLY3553PROT  152-154
   D_ANYEIGHTY  155-157     D_ONLYEIGHTY  158-160    INREPORT  161-163     
   DENIAL_SAMP  164-166     REDUCTM  167-174         OS_SENSPLT0  175-182  
 ;                       

LENGTH
   USSCIDN 6                OS_NEWCNVTN 3            OS_NEWRACE 3          
   OS_NEWCIT 3              OS_ACCAP 3               OS_CAROFFAP 3         
   OS_WEAPSOC 3             OS_OFFGUIDE 3            CRCIRCDIST 3          
   CRGOVOBJ 3               CRMONCIRC 3              MOTSTAT 3             
   CRSENTMON 3              OP_MONSEX 3              SAFEYN 3              
   AGGROLYN 3               MITROLYN 3               OBSTRCYN 3            
   OP_XCRHISSR 3            GUNDUM 3                 TSERVEDM 4            
   SLENGTH 3                CRAGECAT 3               ORIGINATOR 3          
   NONDUP_GREAS1 3          NONDUP_GREAS2 3          NONDUP_GREAS3 3       
   NONDUP_GREAS4 3          NONDUP_GREAS5 3          GC_COVID_ANY 3        
   COVID_CAT 3              CRSENTYPE 3              COL_CRSENTYPE 3       
   UNDUP_GROUPD1 3          UNDUP_GROUPD2 3          UNDUP_GROUPD3 3       
   UNDUP_GROUPD4 3          UNDUP_GROUPD5 3          UNDUP_GROUPD6 3       
   D_ANYEXHAUST 3           D_ONLYEXHAUST 3          D_ANY3553PROT 3       
   D_ONLY3553PROT 3         D_ANYEIGHTY 3            D_ONLYEIGHTY 3        
   INREPORT 3               DENIAL_SAMP 3 ;

     

RUN ;
